StatusCode

Enum StatusCode 

#[non_exhaustive]
pub enum StatusCode {
Show 22 variants Ok, Unknown, NoMemory, InvalidOperation, BadValue, BadType, NameNotFound, PermissionDenied, NoInit, AlreadyExists, DeadObject, FailedTransaction, UnknownTransaction, BadIndex, FdsNotAllowed, UnexpectedNull, NotEnoughData, WouldBlock, TimedOut, BadFd, Errno(i32), ServiceSpecific(i32),
}
Status codes for binder operations.

Represents various error conditions that can occur during binder IPC operations, including system errors, protocol errors, and application-specific errors.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Ok

Operation completed successfully



Unknown

Unknown error occurred



NoMemory

Out of memory



InvalidOperation

Invalid operation for current state



BadValue

Invalid parameter value



BadType

Wrong data type



NameNotFound

Named resource not found



PermissionDenied

Permission denied



NoInit

Object not initialized



AlreadyExists

Resource already exists



DeadObject

Remote object is dead



FailedTransaction

Transaction failed



UnknownTransaction

Unknown transaction code



BadIndex

Invalid array index



FdsNotAllowed

File descriptors not allowed



UnexpectedNull

Unexpected null pointer



NotEnoughData

Not enough data available



WouldBlock

Operation would block



TimedOut

Operation timed out



BadFd

Bad file descriptor



Errno(i32)

System errno value



ServiceSpecific(i32)

Service-specific error code